@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
-/* @(#) $Header: /sources/phpprintipp/phpprintipp/ExtendedPrintIPP.php,v 1.12 2006/01/16 22:16:17 harding Exp $
+/* @(#) $Header: /sources/phpprintipp/phpprintipp/ExtendedPrintIPP.php,v 1.13 2006/01/20 19:49:39 harding Exp $
  *
  * Version: 0.3
  * Class PrintIPP - Send extended IPP requests.
@@ -84,12 +84,15 @@ class ExtendedPrintIPP extends PrintIPP {
         if (self::_sendHttp ($post_values,$this->paths['printers'])) {
             
             if(self::_parseServerOutput()) {
+                $this->_parseJobAttributes();
                 $this->_getJobId();
                 //$this->_getPrinterUri();
                 $this->_getJobUri();
                 }
             }
         
+        $this->attributes = &$this->job_attributes;
+        
         if (isset($this->serveroutput) && isset($this->serveroutput->status)) {
             
             $this->status = array_merge($this->status,array($this->serveroutput->status));
@@ -171,9 +174,10 @@ class ExtendedPrintIPP extends PrintIPP {
         $post_values = array( "Content-Type"=>"application/ipp",
                               "Data"=>$this->output);
             
-        if (self::_sendHttp ($post_values,$this->paths['admin']))
+        if (self::_sendHttp ($post_values,$this->paths['admin'])) {
             self::_parseServerOutput();
-        
+            self::_parseAttributes();
+            }
 
         
         if (isset($this->serveroutput) && isset($this->serveroutput->status)) {
@@ -447,6 +451,8 @@ class ExtendedPrintIPP extends PrintIPP {
 
             }
         
+        $this->attributes = &$this->job_attributes;
+
         if (isset($this->serveroutput) && isset($this->serveroutput->status)) {
             
             $this->status = array_merge($this->status,array($this->serveroutput->status));
@@ -530,9 +536,10 @@ class ExtendedPrintIPP extends PrintIPP {
         $post_values = array( "Content-Type"=>"application/ipp",
                               "Data"=>$this->output);
             
-        if (self::_sendHttp ($post_values,$this->paths['admin']))
+        if (self::_sendHttp ($post_values,$this->paths['admin'])) {
             self::_parseServerOutput();
-        
+            self::_parseAttributes();
+            }
 
         
         if (isset($this->serveroutput) && isset($this->serveroutput->status)) {
@@ -613,9 +620,10 @@ class ExtendedPrintIPP extends PrintIPP {
         $post_values = array( "Content-Type"=>"application/ipp",
                               "Data"=>$this->output);
             
-        if (self::_sendHttp ($post_values,$this->paths['admin']))
+        if (self::_sendHttp ($post_values,$this->paths['admin'])) {
             self::_parseServerOutput();
-        
+            self::_parseAttributes();
+            }
 
         
         if (isset($this->serveroutput) && isset($this->serveroutput->status)) {
@@ -699,9 +707,10 @@ class ExtendedPrintIPP extends PrintIPP {
         $post_values = array( "Content-Type"=>"application/ipp",
                               "Data"=>$this->output);
             
-        if (self::_sendHttp ($post_values,$this->paths['jobs'])) 
+        if (self::_sendHttp ($post_values,$this->paths['jobs'])) {
             self::_parseServerOutput();
-        
+            self::_parseAttributes();
+            }
         if (isset($this->serveroutput) && isset($this->serveroutput->status)) {
             
             $this->status = array_merge($this->status,array($this->serveroutput->status));
@@ -770,9 +779,10 @@ class ExtendedPrintIPP extends PrintIPP {
         $post_values = array( "Content-Type"=>"application/ipp",
                               "Data"=>$this->output);
             
-        if (self::_sendHttp ($post_values,$this->paths['jobs'])) 
+        if (self::_sendHttp ($post_values,$this->paths['jobs'])) {
             self::_parseServerOutput();
-        
+            self::_parseAttributes();
+            }
         if (isset($this->serveroutput) && isset($this->serveroutput->status)) {
             
             $this->status = array_merge($this->status,array($this->serveroutput->status));
@@ -847,8 +857,10 @@ class ExtendedPrintIPP extends PrintIPP {
         $post_values = array( "Content-Type"=>"application/ipp",
                               "Data"=>$this->output);
             
-        if (self::_sendHttp ($post_values,$this->paths['jobs'])) 
+        if (self::_sendHttp ($post_values,$this->paths['jobs'])) {
             self::_parseServerOutput();
+            self::_parseAttributes();
+            }
         
         if (isset($this->serveroutput) && isset($this->serveroutput->status)) {
             
@@ -946,9 +958,10 @@ class ExtendedPrintIPP extends PrintIPP {
         $post_values = array( "Content-Type"=>"application/ipp",
                               "Data"=>$this->output);
             
-        if (self::_sendHttp ($post_values,$this->paths['jobs'])) 
+        if (self::_sendHttp ($post_values,$this->paths['jobs'])) {
             self::_parseServerOutput();
-        
+            self::_parseAttributes();
+            }
         if (isset($this->serveroutput) && isset($this->serveroutput->status)) {
             
             $this->status = array_merge($this->status,array($this->serveroutput->status));
