@@ -42,7 +42,7 @@
 ***********************************************************/
 
 $host = "geekette.localdomain"; // set serve'rs host here
-$ssl = false; // enable ssl if true
+$ssl = true; // enable ssl if true
 $printer_uri = "/printers/epson"; // set printer uri here
 $language = "fr_fr";
 $user = "test"; // valid user from lpadmin group
