@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
- /* @(#) $Header: /sources/phpprintipp/phpprintipp/http_class.php,v 1.3 2006/01/19 17:54:23 harding Exp $
+ /* @(#) $Header: /sources/phpprintipp/phpprintipp/http_class.php,v 1.4 2006/01/20 19:49:39 harding Exp $
  *
  *
  * Version: 0.2 -- E X P E R I M E N T A L
@@ -110,13 +110,6 @@ class http_class {
     // {{{ Open ($arguments)
     public function Open ($arguments) {
         
-        /*
-        echo "<pre>";
-        print_r(stream_get_transports());
-        print_r(stream_get_wrappers());
-        echo "</pre>";
-        */
-
         if (!$this->timeout)
             $this->timeout = 30;
         $url = $arguments["URL"];
@@ -140,7 +133,6 @@ class http_class {
             $port = array_key_exists(1,$url) ? $url[1] : $this->default_port;
             $url = $url[0];
         
-            //echo "$transport_type#$url#$port";flush();
             $this->connection = fsockopen($transport_type.$url, $port, $errno, $errstr, $this->timeout);
         
             if (!$this->connection) 
@@ -298,7 +290,6 @@ class http_class {
 
             if($strselect = stream_select($read, $write = NULL, $except = NULL, 0,$this->data_timeout*1000) === 1) 
                 return "server-talk";
-                //echo "strselect".$strselect."<br />";
 
             if (!$error) {
                 trigger_error(_("Error while ends HTTP headers"),E_USER_WARNING);
@@ -413,23 +404,23 @@ class http_class {
         $content_length = 0;
         if (array_key_exists("content-length",$this->reply_headers));
             $content_length = $this->reply_headers["content-length"];
-            
+
         stream_set_blocking ($this->connection, 0 );
         usleep($this->data_timeout * 1000);
+        $total = 0;
+        $chunk = true;
         while (true) {
-            usleep (1000);
-            $chunk = fread($this->connection,$this->window_size);
-            //echo $content_length."<br />";
             if ($content_length)
                 if (strlen($this->reply_body) >= $content_length)
                     return "completed";
             else
                 if (!$chunk)
                     break;
-
+            usleep (1000);
+            $chunk = fread($this->connection,$this->window_size);
             $this->reply_body .= $chunk;
             }
-
+        stream_set_blocking ($this->connection, 1 );
     return true;
     }
     // }}}
@@ -521,7 +512,6 @@ class http_class {
       
         $this->nc++;
         
-        //echo $auth_scheme;
     return $auth_scheme;
     }
     // }}}
